==> mule-artifact-ast-1.0.0-sources.jar: org/mule/runtime/ast/api/validation/ValidationResultItem.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.api.validation;

import static java.util.Collections.emptyList;
import static java.util.Collections.singletonList;

import org.mule.api.annotation.NoImplement;
import org.mule.runtime.ast.api.ComponentAst;
import org.mule.runtime.ast.api.ComponentParameterAst;
import org.mule.runtime.ast.internal.validation.DefaultValidationResultItem;

import java.util.List;

/**
 * Relates a failing validation to the component where that validation failed.
 *
 * @since 1.0
 */
@NoImplement
public interface ValidationResultItem {

  /**
   * @param component  the component this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(ComponentAst component, Validation validation, String message) {
    return new DefaultValidationResultItem(singletonList(component), emptyList(), validation, message);
  }

  /**
   * @param component  the component this validation result applies to.
   * @param parameter  the parameter form the component this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(ComponentAst component, ComponentParameterAst parameter, Validation validation,
                                            String message) {
    return new DefaultValidationResultItem(singletonList(component), singletonList(parameter), validation, message);
  }

  /**
   * @param component  the component this validation result applies to.
   * @param parameters the parameters form the component this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(ComponentAst component, List<ComponentParameterAst> parameters, Validation validation,
                                            String message) {
    return new DefaultValidationResultItem(singletonList(component), parameters, validation, message);
  }

  /**
   * @param components the components this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(List<ComponentAst> components, Validation validation, String message) {
    return new DefaultValidationResultItem(components, emptyList(), validation, message);
  }

  /**
   * @param components the components this validation result applies to.
   * @param parameters the parameters form the components this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(List<ComponentAst> components, List<ComponentParameterAst> parameters,
                                            Validation validation, String message) {
    return new DefaultValidationResultItem(components, parameters, validation, message);
  }

  /**
   *
   * @return the components this validation result applies to.
   */
  List<ComponentAst> getComponents();

  /**
   *
   * @return the parameters form the components this validation result applies to.
   */
  List<ComponentParameterAst> getParameters();

  /**
   *
   * @return the validation that failed.
   */
  Validation getValidation();

  /**
   *
   * @return the message explaining the reason of the validation failure.
   */
  String getMessage();
}

==> mule-artifact-ast-1.0.1-20250708.224759-159-sources.jar: org/mule/runtime/ast/api/validation/ValidationResultItem.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.api.validation;

import static java.util.Collections.emptyList;
import static java.util.Collections.singletonList;

import org.mule.api.annotation.NoImplement;
import org.mule.runtime.ast.api.ComponentAst;
import org.mule.runtime.ast.api.ComponentParameterAst;
import org.mule.runtime.ast.internal.validation.DefaultValidationResultItem;

import java.util.List;

/**
 * Relates a failing validation to the component where that validation failed.
 *
 * @since 1.0
 */
@NoImplement
public interface ValidationResultItem {

  /**
   * @param component  the component this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(ComponentAst component, Validation validation, String message) {
    return new DefaultValidationResultItem(singletonList(component), emptyList(), validation, message);
  }

  /**
   * @param component  the component this validation result applies to.
   * @param parameter  the parameter form the component this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(ComponentAst component, ComponentParameterAst parameter, Validation validation,
                                            String message) {
    return new DefaultValidationResultItem(singletonList(component), singletonList(parameter), validation, message);
  }

  /**
   * @param component  the component this validation result applies to.
   * @param parameters the parameters form the component this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(ComponentAst component, List<ComponentParameterAst> parameters, Validation validation,
                                            String message) {
    return new DefaultValidationResultItem(singletonList(component), parameters, validation, message);
  }

  /**
   * @param components the components this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(List<ComponentAst> components, Validation validation, String message) {
    return new DefaultValidationResultItem(components, emptyList(), validation, message);
  }

  /**
   * @param components the components this validation result applies to.
   * @param parameters the parameters form the components this validation result applies to.
   * @param validation the validation that failed.
   * @param message    the message explaining the reason of the validation failure.
   * @return an object representing a validation failure.
   */
  public static ValidationResultItem create(List<ComponentAst> components, List<ComponentParameterAst> parameters,
                                            Validation validation, String message) {
    return new DefaultValidationResultItem(components, parameters, validation, message);
  }

  /**
   *
   * @return the components this validation result applies to.
   */
  List<ComponentAst> getComponents();

  /**
   *
   * @return the parameters from the components this validation result applies to.
   */
  List<ComponentParameterAst> getParameters();

  /**
   *
   * @return the validation that failed.
   */
  Validation getValidation();

  /**
   *
   * @return the message explaining the reason of the validation failure.
   */
  String getMessage();
}
